C Common block used in SEDTRANS05
C
C ======================================================================
C                         MAIN
C ======================================================================

c ------------------ parameters ----------------------------------------

      DOUBLE PRECISION G	!GRAVITY
      DOUBLE PRECISION PII	!

      COMMON /MCONST/ G,PII
      SAVE /MCONST/

C ======================================================================
C                         OSCIL 
C ======================================================================

      DOUBLE PRECISION AB       !EXCURSION LENGTH OF BOTTOM WAVE ORBIT (M)
      DOUBLE PRECISION WL       !WAVE LENGTH (M)

      COMMON /OSCL/ AB,WL

C ======================================================================
C                         FRICFAC
C ======================================================================

      DOUBLE PRECISION Z0C      !APPARENT BED ROUGHNESS LENGTH (M)
      DOUBLE PRECISION PHIB     !ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS (RADIANS)
      DOUBLE PRECISION PHI100   !ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS AT 1 M. ABOVE SEABED
      DOUBLE PRECISION DELTACW  !HEIGHT OF THE WAVE-CURRENT BOUNDARY LAYER
      DOUBLE PRECISION USTCS    !CURRENT SKIN-FRICTION SHEAR VELOCITY OF GM
      DOUBLE PRECISION USTWS    !WAVE SKIN-FRICTION SHEAR VELOCITY OF GM
      DOUBLE PRECISION USTCWSE  !EFFECTIVE COMBINED SKIN-FRICTION SHEAR VELOCITY
      DOUBLE PRECISION USTCWSB  !TRANSPORT-RELATED COMBINED SHEAR VELOCITY
      DOUBLE PRECISION USTC     !TOTAL CURRENT SHEAR VELOCITY OF GM
      DOUBLE PRECISION USTW     !TOTAL WAVE SHEAR VELOCITY OF GM
      DOUBLE PRECISION RPLCOEF  !RIPPLE COEFFICIENT FOR SHEAR VELOCITY CONVERSION
      DOUBLE PRECISION RKB      !BOTTOM ROUGHNESS HEIGHT (M)
      DOUBLE PRECISION USTBF	!CRITICAL SHEAR VELOCITY FOR RIPPLE BREAKOFF

      COMMON /FRICF/ Z0C,PHIB,PHI100,DELTACW,USTCS,USTWS,USTCWSE,
     @USTCWSB,USTC,USTW,RPLCOEF,RKB,USTBF

C see also ZOCOH and FCWCOH in common block CCONST

C ======================================================================
C                         TIMING 
C ======================================================================

      DOUBLE PRECISION TB1      !TIME AT WHICH BEDLOAD TRANSPORT CEASES (SEC)
      DOUBLE PRECISION TB2      !TIME AT WHICH BEDLOAD TRANSPORT RECOMMENCES (SEC)
      DOUBLE PRECISION TS1      !TIME AT WHICH SUSPENDED LOAD TRANSPORT CEASES (SEC)
      DOUBLE PRECISION TS2      !TIME AT WHICH SUSPENDED LOAD TRANSPORT RECOMMENCES (SEC)
      DOUBLE PRECISION PERBED   !PERCENTAGE OF TIME SPENT IN ONLY BEDLOAD TRANSPORT PHASE
      DOUBLE PRECISION PERSUSP  !PERCENTAGE OF TIME SPENT IN SUSPENDED LOAD TRANSPORT PHASE

      COMMON /TIMIN/ TB1,TB2,TS1,TS2,PERBED,PERSUSP

C ======================================================================
C                         PROFL 
C ======================================================================

      DOUBLE PRECISION C0       !REFERENCE CONCENTRATION AT Z0 (KG/M^3)
      DOUBLE PRECISION TAOCWS   !AVERAGED EFFECTIVE SHEAR STRESS

      COMMON /PROF/ C0,TAOCWS

      DOUBLE PRECISION ZZ(0:12),CZ(12),UUZ(12)

      COMMON /PROFIL/ ZZ,CZ,UUZ

C ======================================================================
C		         TRANSPO                  
C ======================================================================



C ======================================================================
C		CONSTANTS FOR COHESIVE SEDIMENTS
C ======================================================================
C Common block containing several constant used for the cohesive part of
C sedtrans. It MUST be initialised with an call to INICONST before the first
C call to COHESIVE (or to first call to SEDTRANS05 with IOPT1=7)

      COMMON /CCONST/ CSULVA,TMULVA,TRULVA,RKERO,E0,CDISRUPT,CLIM1,
     &   CLIM2,KFLOC,MFLOC,RHOCLAY,CTAUDEP,PRS,RHOMUD,DPROFA,DPROFB,
     &   DPROFC,DPROFD,DPROFE,CONSOA,TEROA,TEROB,TEROC,TEROD,DISTR,
     &   CDRAGRED,Z0COH,FCWCOH,TAU0EFF,
     &   NDISTR,WSCLAY,MEDDISTR,DOCOMPACT

      SAVE /CCONST/

      DOUBLE PRECISION CSULVA  ! coefficient for the solid transmitted stress by Ulva
      DOUBLE PRECISION TMULVA  ! threshold of motion of   Ulva (Pa)
      DOUBLE PRECISION TRULVA  ! threshold of full resuspension of Ulva (Pa)
      DOUBLE PRECISION RKERO   ! Erosion proportionality coefficient
      DOUBLE PRECISION E0      ! Minimum erosion rate
      DOUBLE PRECISION CDISRUPT! constant for turbulent floc disruption during erosion
      DOUBLE PRECISION CLIM1   ! lower limit for flocculation (kg/m**3)
      DOUBLE PRECISION CLIM2   ! limit between simple and complex flocculation equation (kg/m**3)
      DOUBLE PRECISION KFLOC   ! constant K for flocculation equation
      DOUBLE PRECISION MFLOC   ! constant M for flocculation equation
      DOUBLE PRECISION RHOCLAY ! density of clay mineral
      DOUBLE PRECISION CTAUDEP ! scaling factor for TAUCD
      DOUBLE PRECISION PRS     ! Resuspension probability (range 0-1)
      DOUBLE PRECISION RHOMUD  ! Density of the freshly deposited mud
      DOUBLE PRECISION DPROFA,DPROFB,DPROFC,DPROFD,DPROFE
                               ! constants for final density profile
      DOUBLE PRECISION CONSOA ! time constant of consolidation
      DOUBLE PRECISION TEROA,TEROB,TEROC,TEROD
                               ! constants for erosion threshold from density and overlaying mass
      INTEGER WSCLAY           ! primary median Ws class (must be in the range 1:NBCONC)
      INTEGER MEDDISTR         ! median position of DISTR
      INTEGER DOCOMPACT        ! if not zero, call COMPACT from COHESIVE

      INTEGER NDISTR           ! number of elements used in DISTR
      DOUBLE PRECISION DISTR(15)! (normal) distribution of sediment put in suspension
                               ! the sum of DISTR(1:NDISTR) MUST be exactly 1.0
      DOUBLE PRECISION CDRAGRED! constant for the drag reduction formula

C Common block containing the settling velocity of each Ws class.
C It MUST be initialised with an call to INICONST before the first
C call to COHESIVE (or to first call to SEDISDGM with IOPT1=7)
      COMMON /WSCLASS/ WSI
      DOUBLE PRECISION WSI(30) ! settling velocity of each Ws class (m/s)

      INTEGER NBCONC
      PARAMETER (NBCONC = 21) ! number of Ws classes
                              !  = number of elements in CONC and in WSI

C For subroutine FRICFAC (previous common bloc FRICC
      DOUBLE PRECISION Z0COH    !BED ROUGHNESS LENGHT FOR COHESIVE SEDIMENTS
      DOUBLE PRECISION FCWCOH   !FRICTION FACTOR FOR COHESIVE SEDIMENTS

C Additional result from COHESIVE
      DOUBLE PRECISION TAU0EFF  !effective bed shear stress used in COHESIVE
                                !includes drag reduction and solid transm. stress by Ulva

