C DLL interface subroutine for Sedtrans05
C
C Copyright Urs Neumeier 2005
C
C The input and output variables to Sedtrans05 are bundled into several
C arrays that follow the parameter order of the input/output
C files of the batch version (except the columns IRUN and ERR).
C
C IN1 and IN2 are input variables
C CONC and BEDCHA are input and output variables (used only for cohesive algorithm)
C OUT1, OUT2, OUT3 and PROFILE are output variable
C
C With IOPT1=10, the COHESIVE subroutine is called directly. See explations
C at the end of the comment-header.

C Array IN1(17)  ! Input variables to Sedtrans
C  1: IOPT1    selection of sediment transport equation (1,2,3,4,5,7 or 10)
C  2: D        water depth (m)
C  3: UZ       current speed (m/s)
C  4: Z        height of current measurement (m)
C  5: CDIR     current direction (degrees north)
C  6: HT       wave height (m)
C  7: PER      wave period (seconds)
C  8: WDIR     wave direction (degrees north)
C  9: GD       grain size (m)
C 10: RHINP    ripple height (m)
C 11: RLINP    ripple length (m)
C 12: BETA     bed slope (degree)
C 13: RHOS     grain density (default=2650, kg/m**3)
C 14: SALIN    salinity (default=35)
C 15: TEMP     temperature (degrees Celsius)
C 16: TIMEDR   deposition/erosion duration (seconds)
C 17: AULVA    fraction of bed area covered by Ulva (range 0-1)

C Array IN2(30)  ! Default parameters for cohesive algorithm
C                ! with the value -999. the default value is not modified
C  1: SWITCH    if =0, then IN2 is ignored, in this case IN2 do not have
C                      to be an array, but can be the constant 0
C               if <>0, then IN2 is processed
C  2: CSULVA
C  3: TMULVA
C  4: TRULVA
C  5: RKERO
C  6: E0
C  7: CDISRUPT
C  8: CLIM1
C  9: CLIM2
C 10: KFLOC
C 11: MFLOC
C 12: RHOCLAY
C 13: CTAUDEP
C 14: PRS
C 15: RHOMUD
C 16: DPROFA
C 17: DPROFB
C 18: DPROFC
C 19: DPROFD
C 20: DPROFE
C 21: CONSOA
C 22: TEROA
C 23: TEROB
C 24: TEROC
C 25: TEROD
C 26: CDRAGRED
C 27: Z0COH
C 28: FCWCOH
C 29: WSCLAY
C 30: DOCOMPACT

C CONC(21)       ! Cohesive SSC

C BEDCHA(20,3)   ! Description of cohesive bed
C                  column 1 : depth below surface (m)
C                  column 2 : critical erosion shear stress (Pa)
C                  column 3 : dry bulk density (kg/m3)

C Array OUT1(16) ! Results (similar to file *.dat)
C  1: UB        maximum wave induced orbital velocity at the bottom (m/s)
C  2: FCW       bottom (skin) friction factor
C  3: UA        current speed to be used in bottom stress calc. (m/sec)
C  4: U100      current speed at 1 m. above seabed (m/sec)
C  5: USTCWS    combined skin-friction shear velocity of GM (m/sec)
C  6: USTCW     combined total shear velocity of GM (m/sec)
C  7: Z0        bed roughness length (m)
C  8: FALL      settling velocity for non-cohesive sediment (m/sec)
C  9: RHEIGHT   predicted ripple height (m)
C 10: RLENGTH  predicted ripple length (m)
C 11: C0A      depth averaged reference concentration at z0 (kg/m^3)
C 12: QS       suspended sediment transport rate (kg/m/s)
C 13: QSDIR    direction of suspended sediment transport (degree)
C 14: SEDM     time-averaged net sediment transport as mass (kg/s/m)
C 15: SED      time-averaged net sediment transport as volume (m**3/s/m)
C 16: SEDDIR   direction of net sediment transport (azimuth,degrees)

C Array OUT2(26) ! Results (similar to file *.da2)
C  1: AB        excursion length of bottom wave orbit (m)
C  2: WL        wave length (m)
C  3: USTCRB    critical shear vel for initi of bedload trans (m/sec)
C  4: USTCRS    critical shear vel for initi of suspended load transport (m/sec)
C  5: USTUP     critical shear vel for initn of sheet flow transport (m/sec)
C  6: Z0C       apparent bed roughness length (m)
C  7: PHIB      angle between wave and current directions (radians)
C  8: PHI100    angle between wave and current directions at 1 m. above seabed
C  9: DELTACW  height of the wave-current boundary layer
C 10: USTCS    current skin-friction shear velocity of GM
C 11: USTWS    wave skin-friction shear velocity of GM
C 12: USTCWSE  effective combined skin-friction shear velocity
C 13: USTCWSB  transport-related combined shear velocity
C 14: USTC     total current shear velocity of GM
C 15: USTW     total wave shear velocity of GM
C 16: RPLCOEF  ripple coefficient for shear velocity conversion
C 17: TB1      time at which bedload transport ceases (sec)
C 18: TB2      time at which bedload transport recommences (sec)
C 19: TS1      time at which suspended load transport ceases (sec)
C 20: TS2      time at which suspended load transport recommences (sec)
C 21: PERBED   percentage of time spent in only bedload transport phase
C 22: PERSUSP  percentage of time spent in suspended load transport phase
C 23: C0       reference concentration at z0 (kg/m^3)
C 24: TAOCWS   averaged effective shear stress
C 25: RHOW     water density (kg/m3)
C 26: VISC     dynamic viscosity of water (Pa s)

C Array OUT3(5) ! Results (similar to file *.coh)
C 1: TAUEFF    effective To, includes drag reduction and TAOS (Pa)
C 2: TAOS      solid transmitted stress due to Ulva (Pa)
C 3: ZS        height change in bed surface (m) (positive: erosion, negative: deposition)
C 4: EDRATE    mean erosion/deposition rate (kg/m**2/s) (positive: erosion, negative: deposition)
C 5: TCONC     final total suspended sediment concentration (kg/m**3)

C Array PROFILE(12,3) ! SSC and velocity profile (non-cohesive)
C 1st column: Zi	height above the bed (m)
C 2nd column: Ci	suspended sediment concentration at height Zi (kg/m**3)
C 3rd column: Ui	mean velocity at height Ui (m/s)

C With IOPT1=10, the COHESIVE subroutine is called directly, without passing
C through the main subroutine SEDTRANS05. In this case, CONC, BEDCHA and IN2
C are processed normally, but only followings parameters contained in IN1
C are considered: D, UZ (which then does not represent velocity but
C TAUCWS=RHOW*USTCWS**2), SALIN, TEMP,TIMEDR and AULVA.
C From the output arguments, only RHOW, VISC (in OUT2),
C EDRATE,ZS,SEDM,TCONC,TAOS (in OUT3), CONC and BEDCHA are assigned.
C All the other output arguments are undefined !

      SUBROUTINE SEDTRANS05DLL(IN1,CONC,BEDCHA,IN2,OUT1,OUT2,OUT3,
     &                           PROFILE,BEDTXT)
      IMPLICIT NONE

      INCLUDE "sed_param.h" ! declaration of the COMMON blocks
      INTEGER MAXBED
      PARAMETER (MAXBED=20)

      DOUBLE PRECISION IN1(17)          ! Input variables to Sedtrans
      DOUBLE PRECISION IN2(30)          ! Default parameters for cohesive algorithm
      DOUBLE PRECISION CONC(NBCONC)     ! Cohesive SSC
      DOUBLE PRECISION BEDCHA(MAXBED,3) ! Description of cohesive bed
      DOUBLE PRECISION OUT1(16)         ! Results (similar to file *.dat)
      DOUBLE PRECISION OUT2(26)         ! Results (similar to file *.da2)
      DOUBLE PRECISION OUT3(5)          ! Results (similar to file *.coh)
      DOUBLE PRECISION PROFILE(12,3)    ! SSC and velocity profile (non-cohesive)

      DOUBLE PRECISION D,UZ,Z,CDIR,HT,PER,WDIR,GD,RHINP,RLINP,
     @BETA,RHOS,RHOW,VISC,TIMEDR,AULVA
      INTEGER IOPT1
      DOUBLE PRECISION
     @UB,FCW,UA,U100,USTCWS,USTCW,Z0,RHEIGHT,RLENGTH,QS,QSDIR,SEDM,
     @SED,SEDDIR,FALL,C0A,EDRATE,ZS,TAOS,TCONC,USTCRB,USTCRS,USTUP

      DOUBLE PRECISION TEMP,TAUCWS
      DOUBLE PRECISION SALIN  ! Salinity
      CHARACTER*80 BEDTXT(7)  ! Text of bedform prediction
      INTEGER I   !,J

      CALL INICONST ! initialize the constants in the common blocks

C **********************************************************************
C Copy the input arrays to the input variables
      IOPT1=INT(IN1(1))
      D=IN1(2)
      UZ=IN1(3)
      Z=IN1(4)
      CDIR=IN1(5)
      HT=IN1(6)
      PER=IN1(7)
      WDIR=IN1(8)
      GD=IN1(9)
      RHINP=IN1(10)
      RLINP=IN1(11)
      RHEIGHT=RHINP
      RLENGTH=RLINP
      BETA=IN1(12)
      RHOS=IN1(13)
      SALIN=IN1(14)
      TEMP=IN1(15)
      TIMEDR=IN1(16)
      AULVA=IN1(17)

      IF(IN2(1).NE.0) THEN
         IF(IN2(2).NE.-999.) CSULVA=IN2(2)
         IF(IN2(3).NE.-999.) TMULVA=IN2(3)
         IF(IN2(4).NE.-999.) TRULVA=IN2(4)
         IF(IN2(5).NE.-999.) RKERO=IN2(5)
         IF(IN2(6).NE.-999.) E0=IN2(6)
         IF(IN2(7).NE.-999.) CDISRUPT=IN2(7)
         IF(IN2(8).NE.-999.) CLIM1=IN2(8)
         IF(IN2(9).NE.-999.) CLIM2=IN2(9)
         IF(IN2(10).NE.-999.) KFLOC=IN2(10)
         IF(IN2(11).NE.-999.) MFLOC=IN2(11)
         IF(IN2(12).NE.-999.) RHOCLAY=IN2(12)
         IF(IN2(13).NE.-999.) CTAUDEP=IN2(13)
         IF(IN2(14).NE.-999.) PRS=IN2(14)
         IF(IN2(15).NE.-999.) RHOMUD=IN2(15)
         IF(IN2(16).NE.-999.) DPROFA=IN2(16)
         IF(IN2(17).NE.-999.) DPROFB=IN2(17)
         IF(IN2(18).NE.-999.) DPROFC=IN2(18)
         IF(IN2(19).NE.-999.) DPROFD=IN2(19)
         IF(IN2(20).NE.-999.) DPROFE=IN2(20)
         IF(IN2(21).NE.-999.) CONSOA=IN2(21)
         IF(IN2(22).NE.-999.) TEROA=IN2(22)
         IF(IN2(23).NE.-999.) TEROB=IN2(23)
         IF(IN2(24).NE.-999.) TEROC=IN2(24)
         IF(IN2(25).NE.-999.) TEROD=IN2(25)
         IF(IN2(26).NE.-999.) CDRAGRED=IN2(26)
         IF(IN2(27).NE.-999.) Z0COH=IN2(27)
         IF(IN2(28).NE.-999.) FCWCOH=IN2(28)
         IF(IN2(29).NE.-999.) WSCLAY=INT(IN2(29))
         IF(IN2(30).NE.-999.) DOCOMPACT=INT(IN2(30))
      ENDIF


C **********************************************************************
C Call to SEDTRANS05

      CALL DENSVISC(TEMP,SALIN,RHOW,VISC)
      
      IF(IOPT1.NE.10) THEN

      CALL SEDTRANS05(            ! call to the core-part of Sedtrans
     @D,UZ,Z,CDIR,HT,PER,WDIR,GD,
     @BETA,RHOS,RHOW,IOPT1,VISC,CONC,BEDCHA,MAXBED,TIMEDR,AULVA, !**INPUT VARIABLES**                                					   	!**INPUT VARIABLES**
     @
     @USTCRB,USTCRS,USTUP,UB,FCW,UA,U100,USTCWS,USTCW,Z0,RHEIGHT,
     @RLENGTH,QS,QSDIR,SEDM,SED,SEDDIR,FALL,C0A,EDRATE,ZS,TAOS,
     @TCONC)		!**OUTPUT VARIABLES**

      ELSE
         TAUCWS=IN1(3)
         USTCWS=(TAUCWS/RHOW)**0.5
         U100=0d0
         CALL COHESIVE (CONC,BEDCHA,MAXBED,TIMEDR,USTCWS,U100,D,
     &                        RHOW,VISC/RHOW,AULVA,
     &                        EDRATE,ZS,SEDM,TCONC,TAOS)

      ENDIF

C **********************************************************************
C copy the output variables to the output arrays
      OUT1(1)=UB
      OUT1(2)=FCW
      OUT1(3)=UA
      OUT1(4)=U100
      OUT1(5)=USTCWS
      OUT1(6)=USTCW
      OUT1(7)=Z0
      OUT1(8)=FALL
      OUT1(9)=RHEIGHT
      OUT1(10)=RLENGTH
      OUT1(11)=C0A
      OUT1(12)=QS
      OUT1(13)=QSDIR
      OUT1(14)=SEDM
      OUT1(15)=SED
      OUT1(16)=SEDDIR

      OUT2(1)=AB
      OUT2(2)=WL
      OUT2(3)=USTCRB
      OUT2(4)=USTCRS
      OUT2(5)=USTUP
      OUT2(6)=Z0C
      OUT2(7)=PHIB
      OUT2(8)=PHI100
      OUT2(9)=DELTACW
      OUT2(10)=USTCS
      OUT2(11)=USTWS
      OUT2(12)=USTCWSE
      OUT2(13)=USTCWSB
      OUT2(14)=USTC
      OUT2(15)=USTW
      OUT2(16)=RPLCOEF
      OUT2(17)=TB1
      OUT2(18)=TB2
      OUT2(19)=TS1
      OUT2(20)=TS2
      OUT2(21)=PERBED
      OUT2(22)=PERSUSP
      OUT2(23)=C0
      OUT2(24)=TAOCWS
      OUT2(25)=RHOW
      OUT2(26)=VISC

      OUT3(1)=TAU0EFF
      OUT3(2)=TAOS
      OUT3(3)=ZS
      OUT3(4)=EDRATE
      OUT3(5)=TCONC

      DO 10,I=1,12
         PROFILE(I,1)=ZZ(I)
         PROFILE(I,2)=CZ(I)
         PROFILE(I,3)=UUZ(I)
10    CONTINUE

      DO 20,I=1,7
         BEDTXT(I)=" "
20    CONTINUE
      CALL BEDFORM(U100,UA,UB,GD,FCW,RHOW,RHOS,VISC,IOPT1,
     @RHEIGHT,RLENGTH,USTCWS,USTCRB,USTCRS,USTUP,BEDTXT)    ! predict the bedforms

      END
      

C **********************************************************************
C Alternative entry function, which does not have the output argument
C BEDTXT (character variable that return the bedform prediction).
C All the other arguments are the same than SEDTRANS05DLL.
      
      SUBROUTINE SEDTRANS05DLLA(IN1,CONC,BEDCHA,IN2,OUT1,OUT2,OUT3,
     &                           PROFILE)
      IMPLICIT NONE

      INCLUDE "sed_param.h" ! declaration of the COMMON blocks
      INTEGER MAXBED
      PARAMETER (MAXBED=20)

      DOUBLE PRECISION IN1(17)          ! Input variables to Sedtrans
      DOUBLE PRECISION IN2(30)          ! Default parameters for cohesive algorithm
      DOUBLE PRECISION CONC(NBCONC)     ! Cohesive SSC
      DOUBLE PRECISION BEDCHA(MAXBED,3) ! Description of cohesive bed
      DOUBLE PRECISION OUT1(16)         ! Results (similar to file *.dat)
      DOUBLE PRECISION OUT2(26)         ! Results (similar to file *.da2)
      DOUBLE PRECISION OUT3(5)          ! Results (similar to file *.coh)
      DOUBLE PRECISION PROFILE(12,3)    ! SSC and velocity profile (non-cohesive)
      CHARACTER*80 BEDTXT(7)  ! Text of bedform prediction

      CALL SEDTRANS05DLL(IN1,CONC,BEDCHA,IN2,OUT1,OUT2,OUT3,
     &                           PROFILE,BEDTXT)
      END


      INCLUDE 'cohesive.f'
      INCLUDE 'sedtrans-core.f'
      INCLUDE 'bedform.f'
